IdealCheck

Trait IdealCheck 

pub trait IdealCheck<T> {
    // Required method
    fn contains(&self, value: &T) -> Result<bool, IdealCheckError>;
}
A trait for ideals that implement membership check for an algebraic structure T.

Required Methods

fn contains(&self, value: &T) -> Result<bool, IdealCheckError>

Returns true if an element of the type belongs to this ideal.

Implementors